#!/usr/bin/perl
# Demonstrate direct io control using ftd2xx.dll
use strict;
use Win32::API;
use Carp;
use warnings;

Win32::API->Import( 'ftd2xx', 'ULONG FT_Open(ULONG FT_Open(int iDevice, LPHANDLE handle)');
Win32::API->Import( 'ftd2xx', 'ULONG FT_SetBitMode(HANDLE handle, UCHAR mask, UCHAR mode)');
Win32::API->Import( 'ftd2xx', 'ULONG FT_Read(HANDLE handle, LPCTSTR Buffer, DWORD BytesToRead, LPDWORD BytesRead)');
Win32::API->Import( 'ftd2xx', 'ULONG FT_Write(HANDLE handle, LPCTSTR Buffer, DWORD BytesToWrite, LPDWORD BytesWritten)');
Win32::API->Import( 'ftd2xx', 'ULONG FT_Close(HANDLE handle)');

my $DeviceNumber = 0;
my $ft_handle_p = '1234'; #Preallocate 4 bytes

my $Buffer = pack('C', 0);
my $BytesToWrite = 1;
my $BytesWritten = '1234'; #Preallocate 4 bytes

print "Open device\n";
my $status = FT_Open($DeviceNumber,$ft_handle_p);
my $ft_handle = unpack ('L',$ft_handle_p); #Dereference handle
print "FT_Open returned value: $status\nDeviceHandle - $ft_handle\n\n";


my $mask = pack('C', 0xff);# Set all 8 I/O lines to be outputs
my $mode = 1;	# Set asynchronous bit bashing mode
$status = FT_SetBitMode($ft_handle, $mask, $mode);
print "FT_SetBitMode returned value: $status\nDeviceHandle - $ft_handle\n\n";

for (my $i=0; $i<5; $i++)
{
	$Buffer = pack('C', $i);
	$status = FT_Write($ft_handle, $Buffer, $BytesToWrite, $BytesWritten);
	print "FT_Write returned value: $status\nDeviceHandle - $ft_handle\nBytes Written - ".ord($BytesWritten)."\n";
	print "Buffer - ".ord($Buffer)."\n\n";
	sleep(1);
	$Buffer = $i;
}


$Buffer = pack('C', 0xff);
$status = FT_Write($ft_handle, $Buffer, $BytesToWrite, $BytesWritten);


$status = FT_Close($ft_handle);
print "FT_Close returned value: $status\nDeviceHandle - $ft_handle\n\n";


